import shutil
from pathlib import Path

from fabric import task

PROJECT_NAME = Path(__file__).resolve(strict=True).parent.name


@task
def cleanup(c):
    """清理"""
    for p in Path().glob("**/*"):
        if p.is_dir():
            if p.name == "__pycache__" or not any(p.iterdir()):
                print(p)
                p.rmdir()
        elif p.name == ".DS_Store" or p.suffix == ".pyc":
            print(p)
            p.unlink()


@task
def distribute(c):
    """发布到PyPI"""
    cleanup(c)
    # https://packaging.python.org/en/latest/tutorials/packaging-projects/
    c.run("uv build")
    c.run("uv publish --token $UV_PUBLISH_TOKEN")
    shutil.rmtree("dist")


@task
def format_code(c):
    """格式化代码"""
    c.run("isort .")


@task
def upgrade(c):
    """升级"""
    c.run("curl -fsSL https://raw.githubusercontent.com/nyssance/Free/main/gitignore/Django.gitignore > .gitignore")



from rest_framework.fields import CharField
from rest_framework.serializers import Serializer


class DownloadUrlSerializer(Serializer):
    url = CharField(read_only=True)


class UploadParamsSerializer(Serializer):
    bucket = CharField(write_only=True)
    filename = CharField(write_only=True, required=True)
    key = CharField(read_only=True)
    AWSAccessKeyId = CharField(read_only=True)
    OSSAccessKeyId = CharField(read_only=True)
    acl = CharField(read_only=True)
    success_action_status = CharField(read_only=True)
    ContentType = CharField(read_only=True)
    policy = CharField(read_only=True)
    signature = CharField(read_only=True)
    ContentEncoding = CharField(read_only=True)
    domain = CharField(read_only=True)



import locale


def locale_currency(currency, amount):
    locale.setlocale(locale.LC_ALL, "zh_CN.UTF-8" if currency == "CNY" else "")
    locale._override_localeconv = {"n_sign_posn": 1}
    return locale.currency(amount, grouping=True)
